@@ -8,9 +8,7 @@ import json
 import logging
 import os
 import pathlib
-import random
 import shutil
-import struct
 import subprocess
 import sys
 import time
@@ -117,19 +115,6 @@ def readBinFile(file):
     return data
 
 
-def checkLockFile(lockFile):
-    if os.path.isfile(lockFile):
-        isDebug = sys.executable.endswith("python.exe")
-        if isDebug:
-            print(f"不支持重复执行 {lockFile}")
-            while True:
-                if input("当前调试模式下，输入unlock可继续：") == "unlock":
-                    break
-        else:
-            raise Exception(f"不支持重复执行 {lockFile}")
-    writeFile(lockFile, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
-
-
 def jsonDumps(value):
     return json.dumps(value, ensure_ascii=False, sort_keys=True, separators=(',', ':'))
 
@@ -458,11 +443,12 @@ def strByTimestamp(timestamp=None, fmt=None):
     return time.strftime(fmt, ary)
 
 
-def hold(msg=None, *exitValueList):
+def hold(msg=None, showInput=True, *exitValueList):
     msg = msg or "测试暂停，输入exit可以退出"
     exitValueList = exitValueList or ["exit"]
+    inputFunc = showInput and input or getpass.getpass
     while True:
-        inputValue = getpass.getpass(f"{msg}：")
+        inputValue = inputFunc(f"{msg}：")
         if inputValue in exitValueList:
             return inputValue
 
@@ -681,93 +667,6 @@ async def asyncExecute(*parList):
     return proc.returncode, stdout, stderr
 
 
-class BytesWriter():
-
-    def __init__(self, isBigEndian=True):
-        self.isBigEndian = isBigEndian
-        self.formatAry = []
-        self.valueAry = []
-
-    def toBytes(self):
-        formatStr = self.isBigEndian and ">" or "<"
-        formatStr += "".join(self.formatAry)
-        return struct.pack(formatStr, *self.valueAry)
-
-    def write(self, format, value):
-        self.formatAry.append(format)
-        self.valueAry.append(value)
-
-    def writeAry(self, func, ary):
-        self.writeUInt(len(ary))
-        for value in ary:
-            func(value)
-
-    # -----
-
-    def writeShort(self, value):
-        self.write("h", getLimitedValue(value, -32768, 32767))  # int16
-
-    def writeUShort(self, value):
-        self.write("H", getLimitedValue(value, 0, 65535))  # int16
-
-    def writeInt(self, value):
-        self.write("i", getLimitedValue(value, -2147483648, 2147483647))  # int32
-
-    def writeUInt(self, value):
-        self.write("I", getLimitedValue(value, 0, 4294967295))  # int32
-
-    def writeLong(self, value):
-        self.write("q", getLimitedValue(value, -9223372036854775808, 9223372036854775807))  # int64
-
-    def writeULong(self, value):
-        self.write("Q", getLimitedValue(value, 0, 18446744073709551615))  # int64
-
-    def writeFloat(self, value):
-        self.write("f", value)
-
-    def writeDouble(self, value):
-        self.write("d", value)
-
-    def writeBool(self, value):
-        self.write("?", value)
-
-    def writeStr(self, value):
-        value = value.encode("utf8")
-        self.write(f"{len(value)+1}p", value)
-
-    # -----
-
-    def writeShortAry(self, ary):
-        self.writeAry(self.writeShort, ary)
-
-    def writeUShortAry(self, ary):
-        self.writeAry(self.writeUShort, ary)
-
-    def writeIntAry(self, ary):
-        self.writeAry(self.writeInt, ary)
-
-    def writeUIntAry(self, ary):
-        self.writeAry(self.writeUInt, ary)
-
-    def writeLongAry(self, ary):
-        self.writeAry(self.writeLong, ary)
-
-    def writeULongAry(self, ary):
-        self.writeAry(self.writeULong, ary)
-
-    def writeFloatAry(self, ary):
-        self.writeAry(self.writeFloat, ary)
-
-    def writeDoubleAry(self, ary):
-        self.writeAry(self.writeDouble, ary)
-
-    def writeBoolAry(self, ary):
-        self.writeAry(self.writeBool, ary)
-
-    def writeStrAry(self, ary):
-        self.writeAry(self.writeStr, ary)
-
-
 _maxAsyncHttpNum = 3
 _currentAsyncHttpNum = 0
 _waitAsyncHttpTime = 0.1
