@@ -44,15 +44,7 @@ def open(url):
     driver.get(url)
 
 
-def anotherPage(timeout=DEFAULT_TIMEOUT):
-    if len(driver.window_handles) < 2:
-        WebDriverWait(driver, timeout).until(lambda d: len(driver.window_handles) > 1)
-    for page in driver.window_handles:
-        if page != driver.current_window_handle:
-            driver.switch_to.window(page)
-
-
-def clearAllPages():
+def clearAllTabs():
     ary = driver.window_handles[:]
     for i in range(1, len(ary)):
         driver.switch_to.window(ary[i])
@@ -61,22 +53,7 @@ def clearAllPages():
     driver.get("data:,")
 
 
-def keepCurrentPage():
-    ary = driver.window_handles[:]
-    if driver.current_window_handle in ary:
-        for page in ary:
-            if page != driver.current_window_handle:
-                driver.switch_to.window(page)
-                driver.close()
-    else:
-        for i in range(1, len(ary)):
-            driver.switch_to.window(ary[i])
-    driver.switch_to.window(
-        driver.window_handles[0]
-    )
-
-
-def switchPage(value):
+def switchTab(value):
     if type(value) == int:
         value = driver.window_handles[value]
     else:
@@ -84,7 +61,7 @@ def switchPage(value):
     driver.switch_to.window(value)
 
 
-def closePage(*parList):
+def closeTab(*parList):
     ary = []
     for value in parList:
         if type(value) == int:
@@ -97,7 +74,7 @@ def closePage(*parList):
         driver.close()
 
 
-def closePageExcept(*parList):
+def closeTabExcept(*parList):
     ary = []
     for value in parList:
         if type(value) == int:
@@ -243,7 +220,7 @@ def _checkIsWire():
         raise Exception("不支持操作，init需要指定参数isWire为True")
 
 
-def waitForRequest(url, timeout=None):
+def waitForRequest(url, timeout=DEFAULT_TIMEOUT):
     _checkIsWire()
     driver.wait_for_request(url, timeout)
 
