@@ -31,8 +31,7 @@ def runMain(moduleName=None, **parDict):
     if isAllowRunMain:
         isAllowRunMain = False
         isError = False
-        lockFile = b.getPath(workspacePath, "tool.lock")
-        b.checkLockFile(lockFile)
+        lockFile = checkLockFile()
         isDebug = not not moduleName
         try:
             logFolder = b.getPath(workspacePath, "log")
@@ -101,3 +100,14 @@ def initParDict():
 def isDev():
     return sys.executable.endswith("python.exe")
 
+
+def checkLockFile():
+    lockFile = b.getPath(workspacePath, "task.lock")
+    if os.path.isfile(lockFile):
+        if isDev():
+            print(f"不支持重复执行 {lockFile}")
+            b.hold("当前调试模式下，输入unlock可继续：", True, "unlock")
+        else:
+            raise Exception(f"不支持重复执行 {lockFile}")
+    b.writeFile(lockFile, time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
+    return lockFile
