@@ -1,4 +1,4 @@
-moduleName = "test"
+moduleName = "demo"
 parDict = {}
 
 # moduleName = "buildClr"
